@@ -74,6 +74,11 @@ class AlbumResult(object):
 		self.hash = ''
 		self.url = ''
 
+	def getParseMode(self):
+		if self.cap_html and 'weibo' not in self.url:
+			return 'HTML'
+		return 'Markdown'
+
 	def empty(self):
 		return (not self.imgs) and (not self.cap) and (not self.video)
 
@@ -133,6 +138,8 @@ TO_CLEAN = '#/?'
 def cleanFileName(name):
 	for x in TO_CLEAN:
 		name = name.replace(x, '')
+	if name.split()[0][-1:] == ':':
+		name = name.replace(':', ' ', 1)
 	return name
 
 def getSoup(url):
@@ -169,6 +176,12 @@ def getDisplayChat(chat):
 	else:
 		return chat.title
 
+def getDisplayChatHtml(chat):
+	if chat.username:
+		return '<a href="%s">%s</a>' % ('t.me/' + str(chat.username), chat.title)
+	else:
+		return chat.title
+
 def formatChat(bot, chat_id):
 	try:
 		chat = bot.getChat(chat_id)
@@ -180,7 +193,7 @@ def log_on_fail(debug_group = None, error_to_ignore=[]):
 	def decorate(f):
 		def applicator(*args, **kwargs):
 			try:
-				f(*args,**kwargs)
+				return f(*args,**kwargs)
 			except Exception as e:
 				if str(e) in error_to_ignore:
 					return
@@ -207,6 +220,16 @@ def getDisplayUser(user):
 		result += ' (' + user.username + ')'
 	return '[' + result + '](tg://user?id=' + str(user.id) + ')'
 
+def getDisplayUserHtml(user):
+	result = ''
+	if user.first_name:
+		result += user.first_name
+	if user.last_name:
+		result += ' ' + user.last_name
+	if user.username:
+		result += ' (' + user.username + ')'
+	return '<a href="%s">%s</a>' % ('tg://user?id=' + str(user.id), result)
+
 def splitCommand(text):
 	if not text:
 		return '', ''
@@ -340,14 +363,15 @@ def getLinkFromMsg(msg):
 			return url
 
 def clearUrl(url):
-	for end_char in ['/?utm_source', '?mblogid']:
+	if not url:
+		return ''
+	for end_char in ['/?utm_source', '?mblogid', '&chksm=', 
+			'&amp;chksm=', '&scene=21']:
 		url = url.split(end_char)[0]
-	for end_char in ['#']:
-		if 'id=' not in url:
-			url = url.split(end_char)[0]
-	url = url.split('&chksm=')[0]
+	if not matchKey(url, 'id=', '/#/'):
+		url = url.split('#')[0]
 	if matchKey(url, ['weibo', 'thepaper', 'm.sohu']) and 'id=' not in url: 
 		url = url.split('?')[0]
-	if url.endswith('/'):
-		url = url[:-1]
-	return url
\ No newline at end of file
+	if matchKey(url, ['/s/']):
+		url = url.split('?')[0]
+	return url.strip('/')
\ No newline at end of file
